# ConferenceCorpus
The EventCorpus provides access to academic events and event series from different sources

[![Website ConferenceCorpus](https://img.shields.io/website-up-down-green-red/https/conferencecorpus.bitplan.com.svg)](https://conferencecorpus.bitplan.com)
[![Documentation Status](https://readthedocs.org/projects/conferencecorpus/badge/?version=latest)](https://conferencecorpus.readthedocs.io/en/latest/?badge=latest)
[![Github Actions Build](https://github.com/WolfgangFahl/ConferenceCorpus/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/ConferenceCorpus/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/ConferenceCorpus.svg)](https://pypi.python.org/pypi/ConferenceCorpus/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/ConferenceCorpus.svg)](https://github.com/WolfgangFahl/ConferenceCorpus/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/ConferenceCorpus.svg)](https://github.com/WolfgangFahl/ConferenceCorpus/issues/?q=is%3Aissue+is%3Aclosed)
[![pypi](https://img.shields.io/pypi/pyversions/ConferenceCorpus)](https://pypi.org/project/ConferenceCorpus/)
[![License](https://img.shields.io/github/license/WolfgangFahl/ConferenceCorpus.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Demo
* [Conference Corpus Service](https://conferencecorpus.bitplan.com) 
## Example API calls
* [WEBIST html](https://conferencecorpus.bitplan.com/eventseries/WEBIST?format=html)
* [WEBIST json](https://conferencecorpus.bitplan.com/eventseries/WEBIST?format=json)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/ConferenceCorpus)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
* [Tim Holzheim](https://github.com/tholzheim)
* [Musaab Khan](https://github.com/musaabkh)
